rewriter
========
A simple tool that shows using the syntax API to read in a source file,
parse it, and write it back out again. This can be used for testing purposes,
to make sure syntax trees round trip correctly, or as a basic example of
working with the syntax API.

Usage:

```
rewriter <file-name>
```
